Crate nipdf

Crate nipdf 

Modules

file
Contains types of PDF file structures.
function
graphics
object
object mod contains data structure map to low level pdf objects
parser
text

Enums

ObjectValueError

Functions

log_err
Error logging if the result is an error, panic in debug mode

Type Aliases

Result