Module object

Module object 

object mod contains data structure map to low level pdf objects

Structs

AndValueTypeValidator
If both validator is valid, then the value is valid.
BufPos
Dictionary
DocId
Document id, two binary string.
EqualTypeValueChecker
FilePos
Frame
Frame contains things like xref, trailer, caused by incremental update.
HexString
Decoded PDF literal string object, enclosing ‘(’ and ‘)’ not included.
InlineImage
Contains image data and metadata of inlined image.
InlineStream
IntTypeValueGetter
Implement TypeValueGetter returns i32 value
LiteralString
NameTypeValueGetter
Implement TypeValueGetter returns str value
ObjectId
ObjectWithResolver
Object and resolver, to allow resolve reference from object
OneOfTypeValueChecker
Check type value equals to one of values.
OptionTypeValueChecker
impl TypeValueCheck return true if value is None, otherwise check value using inner.
Reference
RuntimeObjectId
Object id has id and generation, at runtime, generation is not used, RuntimeObjectId removes generation to save space.
SchemaArray
SchemaDict
Stream
TrailerDict
ValueTypeValidator
Implement TypeValidator using TypeValueGetter and TypeValueChecker

Enums

Entry
ImageMask
Object
Pdf basic object types.
ObjectDiscriminants
Auto-generated discriminant enum variants
TextString
TextStringOrNumber
XRefEntry

Traits

FromSchemaContainer
Trait to abstract creation of PdfObject / RootPdfObject
ImageMetadata
Abstract image metadata.for decode image from Stream and InlineStream
PdfObject
PdfObject that has embbed in other container object, such as Dictionary or Array.
PdfObjectCore
RootPdfObject
PdfObject that has reference id
ToPdfObject
TypeValidator
Check type value to validate object Type.
TypeValueCheck
TypeValueGetter
Get type value from Dictionary.

Type Aliases

Array