object mod contains data structure map to low level pdf objects
Structs
- AndValue
Type Validator - If both validator is valid, then the value is valid.
- BufPos
- Dictionary
- DocId
- Document id, two binary string.
- Equal
Type Value Checker - FilePos
- Frame
- Frame contains things like xref, trailer, caused by incremental update.
- HexString
- Decoded PDF literal string object, enclosing ‘(’ and ‘)’ not included.
- Inline
Image - Contains image data and metadata of inlined image.
- Inline
Stream - IntType
Value Getter - Implement
TypeValueGetterreturns i32 value - Literal
String - Name
Type Value Getter - Implement
TypeValueGetterreturns str value - Object
Id - Object
With Resolver - Object and resolver, to allow resolve reference from object
- OneOf
Type Value Checker - Check type value equals to one of
values. - Option
Type Value Checker - impl
TypeValueCheckreturn true if value is None, otherwise check value usinginner. - Reference
- Runtime
Object Id - Object id has id and generation, at runtime, generation is not used, RuntimeObjectId removes generation to save space.
- Schema
Array - Schema
Dict - Stream
- Trailer
Dict - Value
Type Validator - Implement
TypeValidatorusingTypeValueGetterandTypeValueChecker
Enums
- Entry
- Image
Mask - Object
- Pdf basic object types.
- Object
Discriminants - Auto-generated discriminant enum variants
- Text
String - Text
String OrNumber - XRef
Entry
Traits
- From
Schema Container - Trait to abstract creation of PdfObject / RootPdfObject
- Image
Metadata - Abstract image metadata.for decode image from
StreamandInlineStream - PdfObject
- PdfObject that has embbed in other container object, such as Dictionary or Array.
- PdfObject
Core - Root
PdfObject - PdfObject that has reference id
- ToPdf
Object - Type
Validator - Check type value to validate object Type.
- Type
Value Check - Type
Value Getter - Get type value from Dictionary.